QWED Test Report - 2025-12-02

# 🛡️ QWED Comprehensive Test Audit

Generated: 2025-12-02 03:22:53

NEEDS IMPROVEMENT
Total Tests
6
Passed
3
Failed
3
Pass Rate
50.0%
Duration
1.2s

## 📊 Results by Priority

Priority | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
CRITICAL | 4 | 2 | 2 | 50.0%
HIGH | 2 | 1 | 1 | 50.0%
MEDIUM | 0 | 0 | 0 | 0.0%

## 🔧 Results by Engine

Engine | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
STATS | 6 | 3 | 3 | 50.0%

## ❌ Failed Tests (3)

### Detect os module in statistical code

Engine: stats Priority: HIGH ID: STATS_IMP_001

### Detect subprocess in stats code

Engine: stats Priority: CRITICAL ID: STATS_IMP_002

### Detect DataFrame.eval() injection risk

Engine: stats Priority: CRITICAL ID: STATS_SEC_001
'str' object has no attribute 'get'